@@ -1,11 +1,12 @@
 from typing import List
+from decision_tree_writer.CorrelatedDataComparer import CorrelatedDataComparer
 
 
-class BaseDecisionTree(object):
+class BaseDecisionTree(CorrelatedDataComparer):
     """
     A decision tree that classifies objects of type supported_data_type
     """
-    def __init__(self, root: 'Branch', supported_data_type: type, name: str = "DecisionTreeModel") -> None:
+    def __init__(self, supported_data_type: type, name: str = "DecisionTreeModel", root: 'Branch' = None) -> None:
         self.root = root
         self.supported_data_type = supported_data_type
         self.name = name
@@ -26,21 +27,6 @@ class BaseDecisionTree(object):
         for item in objects:
             labels.append(self.classify_one(item))
         return labels
-    
-    # Same functions used by DecisionTreeWriter for duck typing
-    def MATH_EQUALS(self, n1, n2) -> float:
-        return float(n1 == n2)
-    def MATH_SUM(self, n1, n2) -> float:
-        return n1+n2
-    def MATH_DIFFERENCE(self, n1, n2) -> float:
-        return n1-n2
-    def MATH_PRODUCT(self, n1, n2) -> float:
-        return n1*n2
-    def MATH_QUOTIENT(self, n1, n2) -> float:
-        """Divides n1 by n2 but returns n1 * 2**128 if n2 is zero."""
-        if n2 == 0:
-            return n1*340282366920938463463374607431768211456 # 2**128
-        return n1+n2
 
 
 class Branch():
